pub struct NetworkClient { /* private fields */ }Implementations
Sourceimpl NetworkClient
impl NetworkClient
pub const fn new(network_manager: LazyRecipient<NetworkMessage>) -> Self
pub async fn dial(&self, peer_addr: Multiaddr) -> Result<()>
pub async fn listen_on(&self, addr: Multiaddr) -> Result<()>
pub async fn bootstrap(&self) -> Result<()>
pub async fn subscribe(&self, topic: IdentTopic) -> Result<IdentTopic>
pub async fn unsubscribe(&self, topic: IdentTopic) -> Result<IdentTopic>
pub async fn publish( &self, topic: TopicHash, data: Vec<u8>, ) -> Result<MessageId>
pub async fn open_stream(&self, peer_id: PeerId) -> Result<Stream>
pub async fn peer_count(&self) -> usize
pub async fn mesh_peer_count(&self, topic: TopicHash) -> usize
pub async fn mesh_peers(&self, topic: TopicHash) -> Vec<PeerId>
Sourcepub async fn announce_blob(
&self,
blob_id: BlobId,
context_id: ContextId,
size: u64,
) -> Result<()>
pub async fn announce_blob( &self, blob_id: BlobId, context_id: ContextId, size: u64, ) -> Result<()>
Announce a blob to the DHT for a specific context
Sourcepub async fn query_blob(
&self,
blob_id: BlobId,
context_id: Option<ContextId>,
) -> Result<Vec<PeerId>>
pub async fn query_blob( &self, blob_id: BlobId, context_id: Option<ContextId>, ) -> Result<Vec<PeerId>>
Query the DHT for peers that have a specific blob
Sourcepub async fn request_blob(
&self,
blob_id: BlobId,
context_id: ContextId,
peer_id: PeerId,
auth: Option<BlobAuth>,
) -> Result<Option<Vec<u8>>>
pub async fn request_blob( &self, blob_id: BlobId, context_id: ContextId, peer_id: PeerId, auth: Option<BlobAuth>, ) -> Result<Option<Vec<u8>>>
Request a blob from a specific peer
Sourcepub async fn send_specialized_node_verification_request(
&self,
peer_id: PeerId,
request: VerificationRequest,
) -> Result<OutboundRequestId>
pub async fn send_specialized_node_verification_request( &self, peer_id: PeerId, request: VerificationRequest, ) -> Result<OutboundRequestId>
Send a specialized node verification request to a peer
Sourcepub async fn send_specialized_node_invitation_response(
&self,
channel: ResponseChannel<SpecializedNodeInvitationResponse>,
response: SpecializedNodeInvitationResponse,
) -> Result<()>
pub async fn send_specialized_node_invitation_response( &self, channel: ResponseChannel<SpecializedNodeInvitationResponse>, response: SpecializedNodeInvitationResponse, ) -> Result<()>
Send a specialized node invitation response via the response channel